package app.main;

import ryulib.game.GameControl;
import ryulib.game.GamePlatformInfo;
import android.content.Context;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.view.KeyEvent;
import android.view.MotionEvent;

public class Asteroid extends GameControl {

	private static final int _ANIMATIONINTERVAL = 100;
	private static final int _SPEED = 100;
	private static final int _AsreroidSize = 64;

	public Asteroid(Context context, int x, int y) {
		super(null);
		
		_X = x;
		_Y = y;
		
		init(context);
	}

	private Canvas _Canvas = null;
	private Paint _Paint = null;
	
	private int _X = 0;
	private int _Y = 0;
	private double _DY = 0;
	
    private Bitmap[] _Bitmaps = new Bitmap[12];
    private int _BitmapIndex = 0;
    private long _TickCount = 0;
    
    private void init(Context context) {
        Resources resources = context.getResources();
        
        _Bitmaps[11] = BitmapFactory.decodeResource(resources, R.drawable.asteroid01);
        _Bitmaps[10] = BitmapFactory.decodeResource(resources, R.drawable.asteroid02);
        _Bitmaps[ 9] = BitmapFactory.decodeResource(resources, R.drawable.asteroid03);
        _Bitmaps[ 8] = BitmapFactory.decodeResource(resources, R.drawable.asteroid04);
        _Bitmaps[ 7] = BitmapFactory.decodeResource(resources, R.drawable.asteroid05);
        _Bitmaps[ 6] = BitmapFactory.decodeResource(resources, R.drawable.asteroid06);
        _Bitmaps[ 5] = BitmapFactory.decodeResource(resources, R.drawable.asteroid07);
        _Bitmaps[ 4] = BitmapFactory.decodeResource(resources, R.drawable.asteroid08);
        _Bitmaps[ 3] = BitmapFactory.decodeResource(resources, R.drawable.asteroid09);
        _Bitmaps[ 2] = BitmapFactory.decodeResource(resources, R.drawable.asteroid10);
        _Bitmaps[ 1] = BitmapFactory.decodeResource(resources, R.drawable.asteroid11);
        _Bitmaps[ 0] = BitmapFactory.decodeResource(resources, R.drawable.asteroid12);
    }
    
	@Override
	protected void onStart(GamePlatformInfo platformInfo) {
		_Canvas = platformInfo.getCanvas();
		_Paint = platformInfo.getPaint();
	}
	
	@Override
	protected void onTick(GamePlatformInfo platformInfo) {
		long tick = platformInfo.getTick();
		
		_TickCount = _TickCount + tick;
		if (_TickCount >= _ANIMATIONINTERVAL) {
			_TickCount = 0;
			_BitmapIndex++;
			if (_BitmapIndex >= _Bitmaps.length) {
				_BitmapIndex = 0;
			}
		}
		
		// ʴ _SPEED ŭ ӵ  ̵ Ѵ.
		_DY = _DY + (_SPEED * tick / 1000);
		if (_DY >= 1) {
			_Y = _Y + ((int) _DY);
			_DY = _DY - ((int) _DY);
			
			if (_Y > _Canvas.getHeight()) _Y = 0;
		}
	}
	
	@Override
	protected void onDraw(GamePlatformInfo platformInfo) {
		_Canvas.drawBitmap(_Bitmaps[_BitmapIndex], _X, _Y, _Paint);
	}
	
	@Override
	protected boolean onKeyDown(GamePlatformInfo platformInfo, int keyCode, KeyEvent msg) {
		switch (keyCode) {
			case KeyEvent.KEYCODE_DPAD_LEFT: _X--; break;
			case KeyEvent.KEYCODE_DPAD_RIGHT: _X++; break;
		}
		
		return true;
    }
	
	@Override
    protected boolean onTouchEvent(GamePlatformInfo platformInfo, MotionEvent event) {
		int x = (int) event.getX();
		int y = (int) event.getY();
		
		boolean isHori = (x >= _X) && (x <= (_X+_AsreroidSize));
		boolean isVert = (y >= _Y) && (y <= (_Y+_AsreroidSize));
		
		if (isHori && isVert) this.Delete();
		
		return true;
    }
    
}
